@@ -35,4 +35,8 @@ source("script/mod_pfamplot.R")
 source("script/mod_cddplot.R")
 source("script/mod_smartplot.R")
 source("script/mod_plantcareplot.R")
+source("script/mod_plantcareplot2.R")
 source("script/mod_advplot.R")
+source("script/mod_advplot2.R")
+source("script/mod_geneinfo.R")
+source("script/mod_protparam.R")
\ No newline at end of file
